Struct ark_scale::ArkScaleLen
source · #[repr(transparent)]pub struct ArkScaleLen<T, const L: usize>(pub T);Expand description
Arkworks type wrapped for serialization by Scale
Tuple Fields
0: TTrait Implementations
sourceimpl<T: CanonicalDeserialize, const L: usize> ArkScaleMaxEncodedLen for ArkScaleLen<T, L>
impl<T: CanonicalDeserialize, const L: usize> ArkScaleMaxEncodedLen for ArkScaleLen<T, L>
sourcefn max_encoded_len(_: Compress) -> usize
fn max_encoded_len(_: Compress) -> usize
Upper bound, in bytes, of the maximum encoded size of this item.
sourceimpl<T: Clone, const L: usize> Clone for ArkScaleLen<T, L>
impl<T: Clone, const L: usize> Clone for ArkScaleLen<T, L>
sourcefn clone(&self) -> ArkScaleLen<T, L>
fn clone(&self) -> ArkScaleLen<T, L>
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<T: CanonicalDeserialize, const L: usize> Decode for ArkScaleLen<T, L>
impl<T: CanonicalDeserialize, const L: usize> Decode for ArkScaleLen<T, L>
sourcefn decode<I: Input>(input: &mut I) -> Result<Self, Error>
fn decode<I: Input>(input: &mut I) -> Result<Self, Error>
Attempt to deserialise the value from input.
sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>( input: &mut I, dst: &mut MaybeUninit<Self> ) -> Result<DecodeFinished, Error>where I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
sourceimpl<T: CanonicalSerialize, const L: usize> Encode for ArkScaleLen<T, L>
impl<T: CanonicalSerialize, const L: usize> Encode for ArkScaleLen<T, L>
sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
sourcefn encode_to<O: Output + ?Sized>(&self, dest: &mut O)
fn encode_to<O: Output + ?Sized>(&self, dest: &mut O)
Convert self to a slice and append it to the destination.
sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
sourcefn using_encoded<R, F>(&self, f: F) -> Rwhere
F: FnOnce(&[u8]) -> R,
fn using_encoded<R, F>(&self, f: F) -> Rwhere F: FnOnce(&[u8]) -> R,
Convert self to a slice and then invoke the given closure with it.
sourceimpl<T, const L: usize> From<T> for ArkScaleLen<T, L>
impl<T, const L: usize> From<T> for ArkScaleLen<T, L>
sourcefn from(t: T) -> ArkScaleLen<T, L>
fn from(t: T) -> ArkScaleLen<T, L>
Converts to this type from the input type.
sourceimpl<T: PartialEq, const L: usize> PartialEq<ArkScaleLen<T, L>> for ArkScaleLen<T, L>
impl<T: PartialEq, const L: usize> PartialEq<ArkScaleLen<T, L>> for ArkScaleLen<T, L>
sourcefn eq(&self, other: &ArkScaleLen<T, L>) -> bool
fn eq(&self, other: &ArkScaleLen<T, L>) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl<T: CanonicalSerialize, const L: usize> EncodeLike<ArkScaleLen<T, L>> for ArkScaleLen<T, L>
impl<T: Eq, const L: usize> Eq for ArkScaleLen<T, L>
impl<T, const L: usize> StructuralEq for ArkScaleLen<T, L>
impl<T, const L: usize> StructuralPartialEq for ArkScaleLen<T, L>